@@ -6,11 +6,11 @@ Business::Giropay - Giropay payments API
 
 =head1 VERSION
 
-Version 0.102
+Version 0.103
 
 =cut
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 use Business::Giropay::Request::Bankstatus;
 use Business::Giropay::Request::Issuer;
@@ -304,6 +304,14 @@ L<http://api.girocheckout.de/en:tools:transaction_status>.
 
 Add more of Giropay's payment networks.
 
+=head1 AUTHOR
+
+  Peter Mottram (SysPete) <peter@sysnix.com>
+
+=head1 CONTRIBUTORS
+
+  Alexandr Ciornii (chorny)
+
 =head1 ACKNOWLEDGEMENTS
 
 Many thanks to L<CALEVO Equestrian|https://www.calevo.com/> for sponsoring
